should_stream

Function should_stream 

pub fn should_stream(
    content_dir: &Path,
    budget: &MemoryBudget,
    explicitly_set: bool,
) -> bool
Determines whether streaming compilation should be used.

Returns true if the content directory has more files than a single batch can hold, or if --max-memory was explicitly set.